@@ -264,8 +264,7 @@ class RequestHandler(tornado.web.RequestHandler):
         # self.files_db = self.application.settings.get('files_db', NotImplemented)
         # self.dbs = self.application.settings.get('dbs', NotImplemented)
 
-
-        # self.statsd = self.application.settings.get('statsd', NotImplemented)
+        self.statsd = self.application.settings.get('statsd', NotImplemented)
 
         # mail client
         # _smtp_config = self.application.settings.get('smtp')
@@ -283,11 +282,12 @@ class RequestHandler(tornado.web.RequestHandler):
         self.files_db=None
         self.dbs=None
 
-        self.statsd=None
+        # self.statsd=None
+
+
 
 
         self.locale_callback = self.application.settings.get('locale_callback', NotImplemented)
-
         self.hacking_ie = None
 
         # maybe not a good design
